'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var plugin = require('@edtr-io/plugin');
var editorUi = require('@edtr-io/editor-ui');
var ui = require('@edtr-io/ui');
var React = require('react');
var reactSyntaxHighlighter = require('react-syntax-highlighter');
var style = _interopDefault(require('react-syntax-highlighter/dist/cjs/styles/prism/coy'));

var Textarea =
/*#__PURE__*/
ui.styled.textarea({
  height: '250px',
  width: '100%',
  margin: 'auto',
  padding: '10px',
  resize: 'none',
  fontFamily: 'Menlo, Monaco, "Courier New", monospace',
  border: 'none',
  outline: 'none',
  boxShadow: '0 1px 1px 0 rgba(0,0,0,0.50)',
  '&::-webkit-input-placeholder': {
    color: 'rgba(0,0,0,0.5)'
  }
});
var CheckboxContainer =
/*#__PURE__*/
ui.styled.div({
  "float": 'right'
});
function HighlightEditor(props) {
  var config = props.config,
      state = props.state,
      focused = props.focused,
      editable = props.editable;
  var Renderer = config.Renderer;
  var edit = focused && editable;

  var _React$useState = React.useState(edit),
      throttledEdit = _React$useState[0],
      setEditThrottled = _React$useState[1];

  if (edit != throttledEdit) {
    if (!edit) {
      setTimeout(function () {
        setEditThrottled(false);
      }, 500);
    } else {
      setEditThrottled(true);
    }
  }

  return throttledEdit || edit ? React.createElement(React.Fragment, null, React.createElement(Textarea, {
    value: state.code.value,
    name: "text",
    placeholder: "F\xFCge hier deinen Code ein. Verlasse den Bereich, um eine Vorschau zu sehen.",
    onChange: function onChange(e) {
      state.code.set(e.target.value);
    }
  }, state.code.value), React.createElement(editorUi.PrimarySettings, null, React.createElement(editorUi.EditorInput, {
    list: "available-languages",
    label: "Language:",
    value: state.language.value,
    onChange: function onChange(e) {
      state.language.set(e.target.value);
    },
    placeholder: "enter Language"
  }), React.createElement("datalist", {
    id: "available-languages"
  }, ['c', 'javascript', 'jsx', 'markup', 'java', 'python'].map(function (language, index) {
    return React.createElement("option", {
      key: index,
      value: language
    });
  })), React.createElement(CheckboxContainer, null, React.createElement(editorUi.EditorCheckbox, {
    label: "Zeilennummern anzeigen",
    onChange: function onChange() {
      state.showLineNumbers.set(!state.showLineNumbers.value);
    },
    checked: state.showLineNumbers.value
  })))) : React.createElement(Renderer, {
    language: state.language.value,
    showLineNumbers: state.showLineNumbers.value,
    code: state.code.value
  });
}

function HighlightRenderer(props) {
  return React.createElement(reactSyntaxHighlighter.PrismAsyncLight, {
    language: props.language,
    showLineNumbers: props.showLineNumbers,
    style: style,
    customStyle: {
      overflow: 'auto'
    }
  }, props.code || 'Klicke hier und füg deinen Quellcode ein...');
}

/** @public */

var highlightState =
/*#__PURE__*/
plugin.object({
  code:
  /*#__PURE__*/
  plugin.string(''),
  language:
  /*#__PURE__*/
  plugin.string('text'),
  showLineNumbers:
  /*#__PURE__*/
  plugin.boolean(false)
});
/**
 * @param config - {@link HighlightConfig | Plugin configuration}
 * @public
 */

function createHighlightPlugin(config) {
  if (config === void 0) {
    config = {
      Renderer: HighlightRenderer
    };
  }

  return {
    Component: HighlightEditor,
    config: config,
    state: highlightState
  };
}

exports.createHighlightPlugin = createHighlightPlugin;
exports.highlightState = highlightState;
//# sourceMappingURL=plugin-highlight.cjs.development.js.map
